@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
- * Copyright (C) 2008,2009,2010,2011,2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2008,2009,2010,2011,2012,2013 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -43,13 +43,16 @@
 #include <QDesktopWidget>
 #include <QFont>
 #include <QProcess>
+#include <QStringListModel>
 #include <kio/global.h>
 #include <kio/renamedialog.h>
 #include <kjobtrackerinterface.h>
 
 KGpgExternalActions::KGpgExternalActions(KeysManager *parent, KGpgItemModel *model)
 	: QObject(parent),
+	compressionScheme(0),
 	m_model(model),
+	m_kgpgfoldertmp(NULL),
 	m_keysmanager(parent)
 {
 	readOptions();
@@ -57,15 +60,19 @@ KGpgExternalActions::KGpgExternalActions(KeysManager *parent, KGpgItemModel *mod
 
 KGpgExternalActions::~KGpgExternalActions()
 {
+	delete m_kgpgfoldertmp;
 }
 
-void KGpgExternalActions::slotEncryptDroppedFiles(const KUrl::List &urls)
+void KGpgExternalActions::encryptFiles(KeysManager *parent, const KUrl::List &urls)
 {
 	Q_ASSERT(!urls.isEmpty());
 
-	KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(0, m_model, goDefaultKey(), false, urls);
-	connect(dialog, SIGNAL(accepted()), SLOT(slotEncryptionKeySelected()));
+	KGpgExternalActions *encActions = new KGpgExternalActions(parent, parent->getModel());
+
+	KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(parent, parent->getModel(), encActions->goDefaultKey(), false, urls);
+	connect(dialog, SIGNAL(accepted()), encActions, SLOT(slotEncryptionKeySelected()));
 	connect(dialog, SIGNAL(rejected()), dialog, SLOT(deleteLater()));
+	connect(dialog, SIGNAL(rejected()), encActions, SLOT(deleteLater()));
 	dialog->show();
 }
 
@@ -101,64 +108,59 @@ void KGpgExternalActions::slotEncryptionKeySelected()
 			opts << customopts.split(QLatin1Char(' '), QString::SkipEmptyParts);
 	}
 
-	QStringList keys(dialog->selectedKeys());
+	QStringList keys = dialog->selectedKeys();
+
 	if (!defaultKey.isEmpty() && !keys.contains(defaultKey))
 		keys.append(defaultKey);
 
 	if (dialog->getSymmetric())
 		keys.clear();
 
-	KGpgEncrypt *enc = new KGpgEncrypt(parent(), keys, dialog->getFiles(), eopt, opts);
+	KGpgEncrypt *enc = new KGpgEncrypt(dialog->parent(), keys, dialog->getFiles(), eopt, opts);
 	KGpgTransactionJob *encjob = new KGpgTransactionJob(enc);
 
 	KIO::getJobTracker()->registerJob(encjob);
 	encjob->start();
+
+	deleteLater();
 }
 
-void KGpgExternalActions::encryptDroppedFolders(const KUrl::List &urls)
+void KGpgExternalActions::encryptFolders(KeysManager *parent, const KUrl::List &urls)
 {
-	compressionScheme = 0;
-
 	KTemporaryFile *tmpfolder = new KTemporaryFile();
 
 	if (!tmpfolder->open()) {
 		delete tmpfolder;
-		KMessageBox::sorry(m_keysmanager, i18n("Cannot create temporary file for folder compression."), i18n("Temporary File Creation"));
+		KMessageBox::sorry(parent, i18n("Cannot create temporary file for folder compression."), i18n("Temporary File Creation"));
 		return;
 	}
 
-	if (KMessageBox::Continue != KMessageBox::warningContinueCancel(m_keysmanager,
-				i18n("<qt>KGpg will now create a temporary archive file:<br /><b>%1</b> to process the encryption. The file will be deleted after the encryption is finished.</qt>",
+	if (KMessageBox::Continue != KMessageBox::warningContinueCancel(parent,
+				i18n("<qt>KGpg will now create a temporary archive file:<br /><b>%1</b> to process the encryption. "
+				"The file will be deleted after the encryption is finished.</qt>",
 				tmpfolder->fileName()), i18n("Temporary File Creation"), KStandardGuiItem::cont(),
 				KStandardGuiItem::cancel(), QLatin1String( "FolderTmpFile" ))) {
 		delete tmpfolder;
 		return;
 	}
 
-	m_kgpgfoldertmp = tmpfolder;
-
-	KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(m_keysmanager, m_model, goDefaultKey(), false, urls);
+	KGpgExternalActions *encActions = new KGpgExternalActions(parent, parent->getModel());
+	KgpgSelectPublicKeyDlg *dialog = new KgpgSelectPublicKeyDlg(parent, parent->getModel(), encActions->goDefaultKey(), false, urls);
+	encActions->m_kgpgfoldertmp = tmpfolder;
 
 	KHBox *bGroup = new KHBox(dialog->optionsbox);
 
 	(void) new QLabel(i18n("Compression method for archive:"), bGroup);
 
 	KComboBox *optionbx = new KComboBox(bGroup);
-	foreach (const QString &aname, FolderCompressJob::archiveNames())
-		optionbx->addItem(aname);
+	optionbx->setModel(new QStringListModel(FolderCompressJob::archiveNames(), bGroup));
 
-	connect(optionbx, SIGNAL(activated(int)), SLOT(slotSetCompression(int)));
-	connect(dialog, SIGNAL(accepted()), SLOT(startFolderEncode()));
-	connect(dialog, SIGNAL(rejected()), SLOT(slotAbortEnc()));
-
-	dialog->exec();
-}
-
-void KGpgExternalActions::slotAbortEnc()
-{
-	sender()->deleteLater();
-	delete m_kgpgfoldertmp;
-	m_kgpgfoldertmp = NULL;
+	connect(optionbx, SIGNAL(activated(int)), encActions, SLOT(slotSetCompression(int)));
+	connect(dialog, SIGNAL(accepted()), encActions, SLOT(startFolderEncode()));
+	connect(dialog, SIGNAL(rejected()), encActions, SLOT(deleteLater()));
+	connect(dialog, SIGNAL(rejected()), dialog, SLOT(deleteLater()));
+	
+	dialog->show();
 }
 
 void KGpgExternalActions::slotSetCompression(int cp)
@@ -203,17 +205,20 @@ void KGpgExternalActions::startFolderEncode()
 	QFile encryptedFolder(encryptedFile.path());
 	dialog->hide();
 	if (encryptedFolder.exists()) {
-		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(m_keysmanager, i18n("File Already Exists"), KUrl(), encryptedFile, KIO::M_OVERWRITE);
+		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(m_keysmanager, i18n("File Already Exists"),
+				KUrl(), encryptedFile, KIO::M_OVERWRITE);
 		if (over->exec() == QDialog::Rejected) {
 			dialog = NULL;
 			delete over;
+			deleteLater();
 			return;
 		}
 		encryptedFile = over->newDestUrl();
 		delete over;
 	}
 
-	FolderCompressJob *trayinfo = new FolderCompressJob(m_keysmanager, urls, encryptedFile, m_kgpgfoldertmp, selec, encryptOptions, encOptions, compressionScheme);
+	FolderCompressJob *trayinfo = new FolderCompressJob(m_keysmanager, urls, encryptedFile, m_kgpgfoldertmp,
+			selec, encryptOptions, encOptions, compressionScheme);
 	connect(trayinfo, SIGNAL(result(KJob*)), SLOT(slotFolderFinished(KJob*)));
 	KIO::getJobTracker()->registerJob(trayinfo);
 	trayinfo->start();
@@ -224,10 +229,10 @@ void KGpgExternalActions::slotFolderFinished(KJob *job)
 	FolderCompressJob *trayinfo = qobject_cast<FolderCompressJob *>(job);
 	Q_ASSERT(trayinfo != NULL);
 
-	delete m_kgpgfoldertmp;
-	m_kgpgfoldertmp = NULL;
 	if (trayinfo->error())
 		KMessageBox::sorry(m_keysmanager, trayinfo->errorString());
+
+	deleteLater();
 }
 
 void KGpgExternalActions::verifyFile(KUrl url)
@@ -284,15 +289,18 @@ void KGpgExternalActions::slotVerificationDone(int result)
 	}
 }
 
-void KGpgExternalActions::signDroppedFiles(const KUrl::List &urls)
+void KGpgExternalActions::signFiles(KeysManager* parent, const KUrl::List& urls)
 {
 	Q_ASSERT(!urls.isEmpty());
 
-	droppedUrls = urls;
+	KGpgExternalActions *signActions = new KGpgExternalActions(parent, parent->getModel());
 
-	KgpgSelectSecretKey *keydlg = new KgpgSelectSecretKey(0, m_model, false);
-	connect(keydlg, SIGNAL(accepted()), SLOT(slotSignFiles()));
+	signActions->droppedUrls = urls;
+
+	KgpgSelectSecretKey *keydlg = new KgpgSelectSecretKey(parent, parent->getModel(), false);
+	connect(keydlg, SIGNAL(accepted()), signActions, SLOT(slotSignFiles()));
 	connect(keydlg, SIGNAL(rejected()), keydlg, SLOT(deleteLater()));
+	connect(keydlg, SIGNAL(rejected()), signActions, SLOT(deleteLater()));
 	keydlg->show();
 }
 
@@ -314,32 +322,33 @@ void KGpgExternalActions::slotSignFiles()
 		Options << QLatin1String( "--pgp6" );
 
 	if (droppedUrls.count() > 1) {
-		KGpgTextInterface *signFileProcess = new KGpgTextInterface(this, signKeyID, Options);
-		connect(signFileProcess, SIGNAL(fileSignFinished()), SLOT(slotSigningFinished()));
+		KGpgTextInterface *signFileProcess = new KGpgTextInterface(parent(), signKeyID, Options);
+		connect(signFileProcess, SIGNAL(fileSignFinished()), signFileProcess, SLOT(deleteLater()));
 		signFileProcess->signFiles(droppedUrls);
 	} else {
-		KGpgSignText *signt = new KGpgSignText(this, signKeyID, droppedUrls, sopts);
-		connect(signt, SIGNAL(done(int)), SLOT(slotSigningFinished()));
+		KGpgSignText *signt = new KGpgSignText(parent(), signKeyID, droppedUrls, sopts);
+		connect(signt, SIGNAL(done(int)), signt, SLOT(deleteLater()));
 		signt->start();
 	}
+
+	deleteLater();
 }
 
-void KGpgExternalActions::slotSigningFinished()
+void KGpgExternalActions::decryptFiles(KeysManager* parent, const KUrl::List &urls)
 {
-	sender()->deleteLater();
-}
+	KGpgExternalActions *decActions = new KGpgExternalActions(parent, parent->getModel());
 
-void KGpgExternalActions::decryptDroppedFiles(const KUrl::List &urls)
-{
-	m_decryptionFailed.clear();
+	decActions->droppedUrls = urls;
 
-	decryptFile(urls);
+	decActions->decryptFile(urls);
 }
 
 void KGpgExternalActions::decryptFile(KUrl::List urls)
 {
-	if (urls.isEmpty())
+	if (urls.isEmpty()) {
+		deleteLater();
 		return;
+	}
 
 	while (!urls.first().isLocalFile()) {
 		showDroppedFile(urls.takeFirst());
@@ -358,7 +367,8 @@ void KGpgExternalActions::decryptFile(KUrl::List urls)
 	KUrl swapname(first.directory(KUrl::AppendTrailingSlash) + oldname);
 	QFile fgpg(swapname.path());
 	if (fgpg.exists()) {
-		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(m_keysmanager, i18n("File Already Exists"), KUrl(), swapname, KIO::M_OVERWRITE);
+		QPointer<KIO::RenameDialog> over = new KIO::RenameDialog(m_keysmanager,
+				i18n("File Already Exists"), KUrl(), swapname, KIO::M_OVERWRITE);
 		if (over->exec() != QDialog::Accepted) {
 			delete over;
 			urls.pop_front();
@@ -390,18 +400,20 @@ void KGpgExternalActions::slotDecryptionDone(int status)
 
 	if (!droppedUrls.isEmpty()) {
 		decryptFile(droppedUrls);
-	} else if (!m_decryptionFailed.isEmpty()) {
-		KMessageBox::errorList(NULL,
+	} else {
+		if (!m_decryptionFailed.isEmpty()) {
+			KMessageBox::errorList(NULL,
 					i18np("Decryption of this file failed:", "Decryption of these files failed:",
 					m_decryptionFailed.count()), m_decryptionFailed.toStringList(),
 					i18n("Decryption failed."));
+		}
+		deleteLater();
 	}
 }
 
 void KGpgExternalActions::showDroppedFile(const KUrl &file)
 {
 	KgpgEditor *kgpgtxtedit = new KgpgEditor(m_keysmanager, m_model, 0);
-	connect(kgpgtxtedit, SIGNAL(encryptFiles(KUrl::List)), SLOT(slotEncryptDroppedFiles(KUrl::List)));
 	connect(m_keysmanager, SIGNAL(fontChanged(QFont)), kgpgtxtedit, SLOT(slotSetFont(QFont)));
 
 	kgpgtxtedit->m_editor->openDroppedFile(file, false);
@@ -419,7 +431,8 @@ void KGpgExternalActions::readOptions()
 		firstRun();
 	} else if (KGpgSettings::gpgConfigPath().isEmpty()) {
 		if (KMessageBox::Yes == KMessageBox::questionYesNo(0,
-				i18n("<qt>You have not set a path to your GnuPG config file.<br />This may cause some surprising results in KGpg's execution.<br />Would you like to start KGpg's assistant to fix this problem?</qt>"),
+				i18n("<qt>You have not set a path to your GnuPG config file.<br />This may cause some surprising results in KGpg's execution."
+				"<br />Would you like to start KGpg's assistant to fix this problem?</qt>"),
 				QString(), KGuiItem(i18n("Start Assistant")), KGuiItem(i18n("Do Not Start"))))
 			startAssistant();
 	}
