@@ -1,11 +1,8 @@
-/***************************************************************************
-                          kgpgoptions.cpp  -  description
-                             -------------------
-    begin                : Mon Jul 8 2002
-    copyright          : (C) 2002 by Jean-Baptiste Mardelle
-    email                : bj@altern.org
- ***************************************************************************/
-
+/*
+ * Copyright (C) 2002 Jean-Baptiste Mardelle <bj@altern.org>
+ * Copyright (C) 2006,2007,2008,2009,2010,2011,2012,2013
+ *               Rolf Eike Beer <kde@opensource.sf-tec.de>
+ */
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -59,6 +56,7 @@ kgpgOptions::kgpgOptions(QWidget *parent, KGpgItemModel *model)
 
 	m_combomodel->setKeyModel(m_model);
 	m_combomodel->setTrustFilter(KgpgCore::TRUST_MARGINAL);
+	m_combomodel->setEncryptionKeyFilter(true);
 	m_combomodel->sort(0);
 
 	// Initialize the default server and the default server list.
