@@ -22,21 +22,25 @@
 
 KGpgGenerateKey::KGpgGenerateKey(QObject *parent, const QString &name, const QString &email, const QString &comment,
 		const KgpgCore::KgpgKeyAlgo &algorithm, const uint size, const unsigned int expire,
-		const char expireunit)
-	: KGpgTransaction(parent)
+		const char expireunit, const KgpgCore::KgpgSubKeyType capabilities)
+	: KGpgTransaction(parent),
+	m_name(name),
+	m_email(email),
+	m_comment(comment),
+	m_algorithm(algorithm),
+	m_capabilities(capabilities),
+	m_size(size),
+	m_expire(expire),
+	m_expireunit(expireunit)
 {
-	addArgument(QLatin1String( "--status-fd=1" ));
-	addArgument(QLatin1String( "--command-fd=0" ));
-	addArgument(QLatin1String( "--no-verbose" ));
-	addArgument(QLatin1String( "--gen-key" ));
-	addArgument(QLatin1String( "--batch" ));
+	Q_ASSERT((expireunit == 'd') || (expireunit == 'w') ||
+			(expireunit == 'm') || (expireunit == 'y'));
 
-	setName(name);
-	setEmail(email);
-	setComment(comment);
-	setAlgorithm(algorithm);
-	setSize(size);
-	setExpire(expire, expireunit);
+	addArgument(QLatin1String("--status-fd=1"));
+	addArgument(QLatin1String("--command-fd=0"));
+	addArgument(QLatin1String("--no-verbose"));
+	addArgument(QLatin1String("--gen-key"));
+	addArgument(QLatin1String("--batch"));
 
 	getProcess()->setOutputChannelMode(KProcess::SeparateChannels);
 }
@@ -65,7 +69,8 @@ KGpgGenerateKey::preStart()
 void
 KGpgGenerateKey::postStart()
 {
-	QByteArray keymessage("Key-Type: ");
+	QByteArray keymessage = "Key-Type: ";
+
 	switch (m_algorithm) {
 	case KgpgCore::ALGO_RSA:
 		keymessage.append("RSA");
@@ -89,27 +94,51 @@ KGpgGenerateKey::postStart()
 	keymessage.append(keylen);
 	keymessage.append("\nName-Real: ");
 	keymessage.append(m_name.toUtf8());
+
 	if (!m_email.isEmpty()) {
 		keymessage.append("\nName-Email: ");
 		keymessage.append(m_email.toAscii());
 	}
+
 	if (!m_comment.isEmpty()) {
 		keymessage.append("\nName-Comment: ");
 		keymessage.append(m_comment.toUtf8());
 	}
+
 	if (m_expire != 0) {
 		keymessage.append("\nExpire-Date: ");
 		keymessage.append(QByteArray::number(m_expire));
 		keymessage.append(m_expireunit);
 	}
+
+	if (m_capabilities) {
+		keymessage.append("\nKey-Usage: ");
+		QStringList usage;
+#if 0
+		// GnuPG always adds cert, but it does not allow this to be
+		// explicitly specified
+		if (m_capabilities & KgpgCore::SKT_CERTIFICATION)
+			usage << QLatin1String("cert");
+#endif
+		if (m_capabilities & KgpgCore::SKT_AUTHENTICATION)
+			usage << QLatin1String("auth");
+		if (m_capabilities & KgpgCore::SKT_ENCRYPTION)
+			usage << QLatin1String("encrypt");
+		if (m_capabilities & KgpgCore::SKT_SIGNATURE)
+			usage << QLatin1String("sign");
+		keymessage.append(usage.join(QLatin1String(" ")).toAscii());
+	}
+
 	keymessage.append("\nPassphrase: ");
 	write(keymessage, false);
 
 	QString passdlgmessage;
 	if (!m_email.isEmpty()) {
-		passdlgmessage = i18n("<p><b>Enter passphrase for %1 &lt;%2&gt;</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>", m_name, m_email);
+		passdlgmessage = i18n("<p><b>Enter passphrase for %1 &lt;%2&gt;</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>",
+				m_name, m_email);
 	} else {
-		passdlgmessage = i18n("<p><b>Enter passphrase for %1</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>", m_name);
+		passdlgmessage = i18n("<p><b>Enter passphrase for %1</b>:<br />Passphrase should include non alphanumeric characters and random sequences.</p>",
+				m_name);
 	}
 
 	QApplication::restoreOverrideCursor();
@@ -119,7 +148,7 @@ KGpgGenerateKey::postStart()
 bool
 KGpgGenerateKey::nextLine(const QString &line)
 {
-	QString msg(i18n("Generating Key"));
+	QString msg = i18n("Generating Key");
 
 	if (!line.startsWith(QLatin1String("[GNUPG:] ")))
 		return false;
@@ -127,7 +156,8 @@ KGpgGenerateKey::nextLine(const QString &line)
 	int result = false;
 
 	if (line.contains(QLatin1String( "PROGRESS" ))) {
-            QStringList parts(line.mid(18).split(QLatin1Char( ' ' )));
+		const QStringList parts = line.mid(18).split(QLatin1Char(' '));
+
 		if (parts.count() >= 4) {
 			const QString p0(parts.at(0));
 			if (p0 == QLatin1String( "primegen" )) {
@@ -209,57 +239,18 @@ KGpgGenerateKey::newPassphraseEntered()
 	write("%commit");
 }
 
-void
-KGpgGenerateKey::setName(const QString &name)
-{
-	m_name = name;
-}
-
 QString
 KGpgGenerateKey::getName() const
 {
 	return m_name;
 }
 
-void
-KGpgGenerateKey::setEmail(const QString &email)
-{
-	m_email = email;
-}
-
 QString
 KGpgGenerateKey::getEmail() const
 {
 	return m_email;
 }
 
-void
-KGpgGenerateKey::setComment(const QString &comment)
-{
-	m_comment = comment;
-}
-
-void
-KGpgGenerateKey::setAlgorithm(const KgpgCore::KgpgKeyAlgo &algorithm)
-{
-	m_algorithm = algorithm;
-}
-
-void
-KGpgGenerateKey::setSize(const unsigned int size)
-{
-	m_size = size;
-}
-
-void
-KGpgGenerateKey::setExpire(const unsigned int expire, const char expireunit)
-{
-	Q_ASSERT((expireunit == 'd') || (expireunit == 'w') ||
-			(expireunit == 'm') || (expireunit == 'y'));
-	m_expire = expire;
-	m_expireunit = expireunit;
-}
-
 QString
 KGpgGenerateKey::getFingerprint() const
 {
