@@ -368,6 +368,8 @@ KGpgTransactionPrivate::hintNames (void)
 	if (hints.isEmpty()) {
 		hints.insert(KGpgTransaction::HT_KEYEXPIRED, QLatin1String("[GNUPG:] KEYEXPIRED"));
 		hints.insert(KGpgTransaction::HT_SIGEXPIRED, QLatin1String("[GNUPG:] SIGEXPIRED"));
+		hints.insert(KGpgTransaction::HT_NOSECKEY,   QLatin1String("[GNUPG:] NO_SECKEY"));
+		hints.insert(KGpgTransaction::HT_ENCTO,      QLatin1String("[GNUPG:] ENC_TO"));
 	}
 
 	return hints;
@@ -379,6 +381,9 @@ KGpgTransactionPrivate::processDone()
 	m_parent->finish();
 	emit m_parent->infoProgress(100, 100);
 	emit m_parent->done(m_success);
+#ifdef KGPG_DEBUG_TRANSACTIONS
+	kDebug(2100) << this << "result:" << m_success;
+#endif /* KGPG_DEBUG_TRANSACTIONS */
 }
 
 void
@@ -443,7 +448,7 @@ void
 KGpgTransaction::setSuccess(const int v)
 {
 #ifdef KGPG_DEBUG_TRANSACTIONS
-	kDebug(2100) << d->m_success << v;
+	kDebug(2100) << "old" << d->m_success << "new" << v;
 #endif /* KGPG_DEBUG_TRANSACTIONS */
 	d->m_success = v;
 }
